@@ -46,6 +46,7 @@
 #include "panel-menu-button.h"
 #include "panel-globals.h"
 #include "panel-lockdown.h"
+#include "panel-icon-names.h"
 
 enum {
 	TARGET_URL,
@@ -482,7 +483,7 @@ drop_url (PanelWidget *panel,
 
 	panel_launcher_create_from_info (panel->toplevel, position, FALSE,
 					 netscape_url[NETSCAPE_URL_URL],
-					 name, comment, "gnome-globe");
+					 name, comment, PANEL_ICON_REMOTE);
 
 	g_free (comment);
 	g_strfreev (netscape_url);
@@ -521,9 +522,7 @@ drop_uri (PanelWidget *panel,
 	if (!panel_profile_id_lists_are_writable ())
 		return FALSE;
 
-	base = g_path_get_basename (uri);
-	name = gnome_vfs_unescape_string_for_display (base);
-	g_free (base);
+	name = panel_util_get_label_for_uri (base);
 
 	comment = gnome_vfs_unescape_string_for_display (uri);
 
@@ -654,6 +653,7 @@ drop_urilist (PanelWidget *panel,
 			} else {
 				char *icon;
 
+				//FIXME: use panel_util_get_icon_for_uri
 				icon = gnome_icon_lookup (gtk_icon_theme_get_default (),
 							  NULL, NULL, NULL,
 							  info, info->mime_type,
@@ -661,7 +661,7 @@ drop_urilist (PanelWidget *panel,
 							  NULL);
 
 				if (!icon)
-					icon = g_strdup ("gnome-unknown");
+					icon = g_strdup (PANEL_ICON_UNKNOWN);
 
 				if (!drop_uri (panel, pos, uri, icon))
 					success = FALSE;
@@ -669,7 +669,7 @@ drop_urilist (PanelWidget *panel,
 				g_free (icon);
 			}
 		} else {
-			if (!drop_uri (panel, pos, uri, "gnome-unknown"))
+			if (!drop_uri (panel, pos, uri, PANEL_ICON_UNKNOWN))
 				success = FALSE;
 		}
 
@@ -1082,7 +1082,7 @@ panel_receive_dnd_data (PanelWidget      *panel,
 		break;
 	case TARGET_DIRECTORY:
 		success = drop_uri (panel, pos, (char *)selection_data->data,
-				    "gnome-fs-directory");
+				    PANEL_ICON_FOLDER);
 		break;
 	case TARGET_APPLET:
 		if (!selection_data->data) {
@@ -1301,24 +1301,21 @@ panel_deletion_dialog (PanelToplevel *toplevel)
 	GtkWidget *dialog;
 	char *text1;
 	char *text2;
-	char *title;
 
 	if (panel_toplevel_get_is_attached (toplevel)) {
 		text1 = _("Delete this drawer?");
 		text2 = _("When a drawer is deleted, the drawer and its\n"
 			 "settings are lost.");
-		title = _("Delete Drawer");
 	} else {
 		text1 = _("Delete this panel?");
 		text2 = _("When a panel is deleted, the panel and its\n"
 			 "settings are lost.");
-		title = _("Delete Panel");
 	}
 
 	dialog = gtk_message_dialog_new (
 			GTK_WINDOW (toplevel),
 			GTK_DIALOG_MODAL,
-			GTK_MESSAGE_QUESTION,
+			GTK_MESSAGE_WARNING,
 			GTK_BUTTONS_NONE,
 			text1);
 	
@@ -1330,10 +1327,6 @@ panel_deletion_dialog (PanelToplevel *toplevel)
 				NULL);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-	gtk_window_set_title (GTK_WINDOW (dialog), title);
-
-	gtk_window_set_wmclass (GTK_WINDOW (dialog),
-				"panel_remove_query", "Panel");
 
 	gtk_window_set_screen (GTK_WINDOW (dialog),
 				gtk_window_get_screen (GTK_WINDOW (toplevel)));
